@@ -149,11 +149,16 @@ def handle_sslverify_fornumericip( ) :
         return
 
     #s_log.write(endpoint_url)
+
     purl = s_util.url_parse( endpoint_url )
     #s_log.write(purl.scheme)
     #s_log.write(purl.hostname)
     #s_log.write(purl.port)
 
+    if(purl.port!="443"):
+        set_key_alt( "endpoint/sslverify" , "no" )
+        return
+
     if( not purl.hostname ) :
         return
 
@@ -388,12 +393,13 @@ def init( config_user = None ) :
     config[ "/config/init/time" ] = t1
     config[ "/config/init/time_lap" ] = t1
     config[ "/config/version" ] = get_version( )
-    config[ "/config/cwd" ] = os.getcwd( )
-    #config[ "/config/scriptdir" ] = os.path.dirname( os.path.realpath( __file__ ) )
+
     config[ "/config/session" ] = s_util.uhash( )
 
-
-    config[ "/config/parentpath" ] = s_util.parent_path()
+    # FIXME TODO check usage of following key values 
+    config[ "/config/cwd" ] = os.getcwd( )
+    #config[ "/config/scriptdir" ] = os.path.dirname( os.path.realpath( __file__ ) )
+    config[ "/config/parentpath" ] = s_util.parent_path( )
 
     #s_log.write( config )
 
