@@ -241,7 +241,7 @@ def init_schema( ) :
 
     ################################################################
 
-    sql_execute( "CREATE TABLE files ( fp text UNIQUE , fc blob , fs integer , fh text )" )
+    sql_execute( "CREATE TABLE files ( fp text UNIQUE , fc blob , fs integer , fh text , fm integer )" )
     sql_execute( "CREATE INDEX index_files ON files ( fp )" )
 
     ################################################################
@@ -599,10 +599,13 @@ def files_create( fp , trimpath = "" ) :
         #s_log.write( "trimpath=" + trimpath )
         fp_processed = fp.lstrip( trimpath )
 
+
+    statinfo = os.stat( fp )
+
     ####################################################################
 
-    sql = "INSERT INTO files ( fp , fc , fs , fh ) VALUES (?, ?, ?, ?)"
-    data_tuple = ( fp_processed , fc , fs , fh )
+    sql = "INSERT INTO files ( fp , fc , fs , fh , fm ) VALUES (?, ?, ?, ?,?)"
+    data_tuple = ( fp_processed , fc , fs , fh , statinfo.st_mtime)
 
     sql_execute( sql , data_tuple )
 
@@ -647,6 +650,8 @@ def files_dict2json( fp , fdict ) :
     fs = len( fc )
     fh = hashlib.md5( fc.encode( "utf-8" ) ).hexdigest( )
 
+    # FIXME TODO add fm
+
     sql = "INSERT INTO files ( fp , fc , fs , fh ) VALUES (?, ?, ?, ?)"
     data_tuple = ( fp , fc , fs , fh )
     sql_execute( sql , data_tuple )
@@ -668,12 +673,13 @@ def files_write( fp ) :
 
 def files_readallmeta( ) :
 
-    sql = "SELECT fp,fs,fh FROM files" 
+    sql = "SELECT fp,fs,fh,fm FROM files" 
     rows = sql_execute_fetch( sql , fetch_all = True )
     return( rows )
 
 def files_restore( ) :
-    db_files=files_readallmeta( )
+    db_files = files_readallmeta( )
+    s_log.write(db_files)
     for db_file in db_files :
 
         fp = db_file[ "fp" ]
