@@ -134,7 +134,7 @@ def job_request( params = { } ) :
         s_log.write( "FOUND _header_extra" )
         headers[ "X-Omni-Extra" ] = s_util.json_encode( header_extra )
 
-    s_log.write( headers )
+    #s_log.write( headers )
 
     res = get_request_response( headers , payload )
 
@@ -156,6 +156,8 @@ def job_request( params = { } ) :
 
     #####################################################################
 
+    # s_log.write(str(res.headers))
+
     jid = res.headers[ "X-Omni-Jid" ]
 
     s_log.write( "job_request [" + jid + "]" )
