@@ -172,6 +172,22 @@ def runner_omnibus( path_runner ) :
     # Required to make module name scope available in function for importlib
     global _sapi_runner_omnibus
 
+
+    ###############################################################################
+    # _CONTAINER_LOCAL_APPSAPIENABLED
+
+    env_appsapienabled = s_util.environ_get("_CONTAINER_LOCAL_APPSAPIENABLED")
+    if( env_appsapienabled == None ) :
+        s_log.write("_CONTAINER_LOCAL_APPSAPIENABLED NONE DISABLED")
+        s_util.idle( )
+
+    if( env_appsapienabled.endswith("_APPSAPIENABLED_")) :
+        s_log.write("_CONTAINER_LOCAL_APPSAPIENABLED ENDSWITH DISABLED")
+        s_util.idle( )
+
+    ###############################################################################
+
+
     s_log.write( "RUNNER_OMNIBUS START " + path_runner )
 
     if( not s_util.sys_path_append_fp( path_runner ) ) :
